=====
eyepy
=====



This software is under active development and can not be considered stable


Features
--------

* Read the HEYEX XML export
* Read the HEYEX VOL export
* Plot OCT Scans

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
